==> nextcloud-14.0.4.tar.bz2: nextcloud/lib/l10n/id.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Tidak dapat menulis kedalam direktori \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Hal ini biasanya dapat diperbaiki dengan memberikan akses tulis bagi situs web ke direktori config",
    "See %s" : "Lihat %s",
    "Sample configuration detected" : "Konfigurasi sampel ditemukan",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ditemukan bahwa konfigurasi sampel telah disalin. Hal ini dapat merusak instalasi Anda dan tidak didukung. Silahkan baca dokumentasi sebelum melakukan perubahan pada config.php",
    "PHP %s or higher is required." : "Diperlukan PHP %s atau yang lebih tinggi.",
    "PHP with a version lower than %s is required." : "Diperlukan PHP dengan versi yang lebh rendah dari %s.",
    "%sbit or higher PHP required." : "PHP %sbit atau yang lebih tinggi diperlukan.",
    "Following databases are supported: %s" : "Berikut adalah basis data yang didukung: %s",
    "The command line tool %s could not be found" : "Alat baris perintah %s tidak ditemukan",
    "The library %s is not available." : "Pustaka %s tidak tersedia.",
    "Following platforms are supported: %s" : "Berikut adalah platform yang didukung: %s",
    "Server version %s or higher is required." : "Server versi %s atau yang lebih tinggi diperlukan.",
    "Server version %s or lower is required." : "Server versi %s atau yang lebih rendah diperlukan.",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "today" : "hari ini",
    "yesterday" : "kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "last month" : "bulan kemarin",
    "_%n month ago_::_%n months ago_" : ["%n bulan yang lalu"],
    "last year" : "tahun kemarin",
    "_%n year ago_::_%n years ago_" : ["%n tahun yang lalu"],
    "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
    "seconds ago" : "beberapa detik yang lalu",
    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
    "File name is too long" : "Nama berkas terlalu panjang",
    "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
    "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikasi \"%s\" tidak dapat dipasang karena berkas appinfo tidak dapat dibaca.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikasi \"%s\" tidak dapat dipasang karena tidak kompatibel dengan versi server ini",
    "__language_name__" : "Bahasa Indonesia",
    "Help" : "Bantuan",
    "Apps" : "aplikasi",
    "Log out" : "Keluar",
    "Users" : "Pengguna",
    "Unknown user" : "Pengguna tidak dikenal",
    "%s enter the database username and name." : "%s masukkan nama pengguna database dan nama database.",
    "%s enter the database username." : "%s masukkan nama pengguna basis data.",
    "%s enter the database name." : "%s masukkan nama basis data.",
    "%s you may not use dots in the database name" : "%s anda tidak boleh menggunakan karakter titik pada nama basis data",
    "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
    "Oracle username and/or password not valid" : "Nama pengguna dan/atau kata sandi Oracle tidak sah",
    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau kata sandi PostgreSQL tidak valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
    "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
    "Set an admin username." : "Tetapkan nama pengguna admin.",
    "Set an admin password." : "Tetapkan kata sandi admin.",
    "Can't create or write into the data directory %s" : "Tidak dapat membuat atau menulis kedalam direktori data %s",
    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Gagal berbagi %s, karena backend tidak mengizinkan berbagi dengan tipe %i",
    "Sharing %s failed, because the file does not exist" : "Gagal membagikan %s, karena berkas tidak ada",
    "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
    "Sharing %s failed, because you can not share with yourself" : "Berbagi %s gagal, karena Anda tidak dapat berbagi dengan diri sendiri",
    "You need to provide a password to create a public link, only protected links are allowed" : "Anda perlu memberikan kata sandi untuk membuat tautan publik, hanya tautan yang terlindungi yang diizinkan",
    "Sharing %s failed, because sharing with links is not allowed" : "Gagal membagikan %s, karena berbag dengan tautan tidak diizinkan",
    "Not allowed to create a federated share with the same user" : "Tidak diizinkan membuat pembagian terfederasi dengan pengguna yang sama",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Tidak dapat menyetel tanggal kadaluarsa. Pembagian tidak dapat kadaluarsa lebih lambat dari %s setelah mereka dibagikan.",
    "Cannot set expiration date. Expiration date is in the past" : "Tidak dapat menyetel tanggal kadaluarsa. Tanggal kadaluarsa dimasa lalu",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
    "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
    "Sharing failed, because the user %s is the original sharer" : "Berbagi gagal, karena pengguna %s adalah pembagi awal",
    "Sharing %s failed, because resharing is not allowed" : "Gagal berbagi %s, karena membagikan ulang tidak diizinkan",
    "Sharing %s failed, because the file could not be found in the file cache" : "Gagal berbagi %s, karena berkas tidak ditemukan di berkas cache",
    "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
    "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Hanya karakter ini yang diizinkan dalam nama pengguna: \"a-z\", \"A-Z\", \"0-9\", dan \"_.@-'\"",
    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
    "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
    "A valid password must be provided" : "Tuliskan kata sandi yang valid",
    "The username is already being used" : "Nama pengguna ini telah digunakan",
    "User disabled" : "Pengguna dinonaktifkan",
    "Login canceled by app" : "Log masuk dibatalkan oleh aplikasi",
    "a safe home for all your data" : "rumah yang aman untuk semua datamu",
    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
    "Can't read file" : "Tidak dapat membaca berkas",
    "Application is not enabled" : "aplikasi tidak diaktifkan",
    "Authentication error" : "Galat saat otentikasi",
    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
    "Cannot write into \"config\" directory" : "Tidak dapat menulis kedalam direktori \"config\"",
    "Cannot write into \"apps\" directory" : "Tidak dapat menulis kedalam direktori \"apps\"",
    "Setting locale to %s failed" : "Pengaturan lokal ke %s gagal",
    "Please install one of these locales on your system and restart your webserver." : "Mohon instal paling tidak satu lokal pada sistem Anda dan jalankan ulang server web.",
    "Please ask your server administrator to install the module." : "Mohon tanyakan administrator Anda untuk menginstal module.",
    "PHP module %s not installed." : "Module PHP %s tidak terinstal.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Pengaturan PHP \"%s\" tidak diatur ke \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Menyesuaikan pengaturan ini di php.ini akan membuat Nextcloud berjalan kembali",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload diatur menjadi \"%s\" bukan nilai yang diharapkan \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Untuk memperbaiki masalah ini, atur <code>mbstring.func_overload</code> menjadi <code>0</code> pada berkas php.ini Anda",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Setidaknya libxml2 2.7.0 dibutuhkan. Saat ini %s dipasang.",
    "To fix this issue update your libxml2 version and restart your web server." : "Untuk mengatasi masalah ini, perbarui versi libxml2 Anda dan mulai-ulang server web Anda.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Tampaknya PHP diatur untuk memotong inline doc blocks. Hal ini akan menyebabkan beberapa aplikasi inti menjadi tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
    "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
    "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
    "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
    "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda",
    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
    "Storage unauthorized. %s" : "Penyimpanan tidak terotorisasi. %s",
    "Storage incomplete configuration. %s" : "Konfigurasi penyimpanan tidak terselesaikan. %s",
    "Storage connection error. %s" : "Koneksi penyimpanan bermasalah. %s",
    "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
    "Library %s with a version higher than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih tinggi dari %s - versi yang tersedia %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Diperlukan pustaka %s dengan versi yang lebih rendah dari %s - versi yang tersedia %s.",
    "Sharing %s failed, because the user %s does not exist" : "Gagal membagikan %s, karena pengguna %s tidak ada",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Gagal membagikan %s, karena pengguna %s bukan merupakan anggota dari grup yang %s ikuti",
    "Sharing %s failed, because this item is already shared with %s" : "Gagal membagkan %s, karena item ini sudah dibagikan dengan %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
    "Sharing %s failed, because the group %s does not exist" : "Gagal membagikan %s, karena grup %s tidak ada",
    "Sharing %s failed, because %s is not a member of the group %s" : "Gagal membagikan %s, karena %s bukan anggota dari grup %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Berbagi %s gagal, tidak menemukan %s, kemungkinan saat ini server tidak dapat dijangkau.",
    "Share type %s is not valid for %s" : "Barbagi tipe %s tidak sah untuk %s",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Gagal membagikan %s, karena izin melebihi izin yang diberikan untuk %s",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Berbagi %s gagal, karena backend berbagi untuk %s tidak menemukan sumbernya",
    "%s shared »%s« with you" : "%s membagikan »%s« dengan anda",
    "%s via %s" : "%s melalui %s",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "aplikasi \"%s\" tidak dapat dipasang karena dependensi berikut belum terpenuhi: %s"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.6.tar.bz2: nextcloud/lib/l10n/id.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Tidak dapat menulis kedalam direktori \"config\"!",
    "See %s" : "Lihat %s",
    "Sample configuration detected" : "Konfigurasi sampel ditemukan",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ditemukan bahwa konfigurasi sampel telah disalin. Hal ini dapat merusak instalasi Anda dan tidak didukung. Silahkan baca dokumentasi sebelum melakukan perubahan pada config.php",
    "Other activities" : "Aktifitas lain",
    "PHP %s or higher is required." : "Diperlukan PHP %s atau yang lebih tinggi.",
    "PHP with a version lower than %s is required." : "Diperlukan PHP dengan versi yang lebh rendah dari %s.",
    "%sbit or higher PHP required." : "PHP %sbit atau yang lebih tinggi diperlukan.",
    "The command line tool %s could not be found" : "Alat baris perintah %s tidak ditemukan",
    "The library %s is not available." : "Pustaka %s tidak tersedia.",
    "Server version %s or higher is required." : "Server versi %s atau yang lebih tinggi diperlukan.",
    "Server version %s or lower is required." : "Server versi %s atau yang lebih rendah diperlukan.",
    "Authentication" : "Otentikasi",
    "Unknown filetype" : "Tipe berkas tak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "View profile" : "Tampilkan profil",
    "today" : "hari ini",
    "yesterday" : "kemarin",
    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
    "last month" : "bulan kemarin",
    "_%n month ago_::_%n months ago_" : ["%n bulan yang lalu"],
    "last year" : "tahun kemarin",
    "_%n year ago_::_%n years ago_" : ["%n tahun yang lalu"],
    "_%n hour ago_::_%n hours ago_" : ["%n jam yang lalu"],
    "_%n minute ago_::_%n minutes ago_" : ["%n menit yang lalu"],
    "seconds ago" : "beberapa detik yang lalu",
    "File already exists" : "Berkas sudah ada",
    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
    "File name is too long" : "Nama berkas terlalu panjang",
    "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
    "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikasi \"%s\" tidak dapat dipasang karena berkas appinfo tidak dapat dibaca.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikasi \"%s\" tidak dapat dipasang karena tidak kompatibel dengan versi server ini",
    "__language_name__" : "Bahasa Indonesia",
    "Help" : "Bantuan",
    "Apps" : "Aplikasi",
    "Settings" : "Setelan",
    "Log out" : "Keluar",
    "Users" : "Pengguna",
    "Email" : "Surel",
    "Phone" : "Telpon",
    "Twitter" : "Twitter",
    "Website" : "Situs",
    "Address" : "Alamat",
    "Profile picture" : "Foto profil",
    "About" : "Tentang.",
    "Full name" : "Nama lengkap",
    "Unknown user" : "Pengguna tidak dikenal",
    "Additional settings" : "Setelan tambahan",
    "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
    "Oracle username and/or password not valid" : "Nama pengguna dan/atau kata sandi Oracle tidak sah",
    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau kata sandi PostgreSQL tidak valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
    "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
    "Set an admin username." : "Tetapkan nama pengguna admin.",
    "Set an admin password." : "Tetapkan kata sandi admin.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
    "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
    "Open »%s«" : "Buka »%s«",
    "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
    "Cannot increase permissions of %s" : "Tidak dapat menambah izin %s",
    "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
    "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
    "Sunday" : "Minggu",
    "Monday" : "Senin",
    "Tuesday" : "Selasa",
    "Wednesday" : "Rabu",
    "Thursday" : "Kamis",
    "Friday" : "Jumat",
    "Saturday" : "Sabtu",
    "Sun." : "Min.",
    "Mon." : "Sen.",
    "Tue." : "Sel.",
    "Wed." : "Rab.",
    "Thu." : "Kam.",
    "Fri." : "Jum.",
    "Sat." : "Sab.",
    "Su" : "Min",
    "Mo" : "Sen",
    "Tu" : "Sel",
    "We" : "Rab",
    "Th" : "Kam",
    "Fr" : "Jum",
    "Sa" : "Sab",
    "January" : "Januari",
    "February" : "Februari",
    "March" : "Maret",
    "April" : "April",
    "May" : "Mei",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Agustus",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mei",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Agu.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Hanya karakter ini yang diizinkan dalam nama pengguna: \"a-z\", \"A-Z\", \"0-9\", dan \"_.@-'\"",
    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
    "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
    "A valid password must be provided" : "Tuliskan kata sandi yang valid",
    "The username is already being used" : "Nama pengguna ini telah digunakan",
    "User disabled" : "Pengguna dinonaktifkan",
    "Login canceled by app" : "Log masuk dibatalkan oleh aplikasi",
    "a safe home for all your data" : "rumah yang aman untuk semua datamu",
    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
    "Application is not enabled" : "aplikasi tidak diaktifkan",
    "Authentication error" : "Galat saat otentikasi",
    "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tidak ada driver (sqlite, mysql, or postgresql) yang terinstal.",
    "PHP module %s not installed." : "Module PHP %s tidak terinstal.",
    "Please ask your server administrator to install the module." : "Mohon tanyakan administrator Anda untuk menginstal module.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Pengaturan PHP \"%s\" tidak diatur ke \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Menyesuaikan pengaturan ini di php.ini akan membuat Nextcloud berjalan kembali",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Setidaknya libxml2 2.7.0 dibutuhkan. Saat ini %s dipasang.",
    "To fix this issue update your libxml2 version and restart your web server." : "Untuk mengatasi masalah ini, perbarui versi libxml2 Anda dan mulai-ulang server web Anda.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Tampaknya PHP diatur untuk memotong inline doc blocks. Hal ini akan menyebabkan beberapa aplikasi inti menjadi tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
    "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
    "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
    "Storage unauthorized. %s" : "Penyimpanan tidak terotorisasi. %s",
    "Storage incomplete configuration. %s" : "Konfigurasi penyimpanan tidak terselesaikan. %s",
    "Storage connection error. %s" : "Koneksi penyimpanan bermasalah. %s",
    "Storage is temporarily not available" : "Penyimpanan sementara tidak tersedia",
    "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
    "%s enter the database username and name." : "%s masukkan nama pengguna database dan nama database.",
    "%s enter the database username." : "%s masukkan nama pengguna basis data.",
    "%s enter the database name." : "%s masukkan nama basis data.",
    "%s you may not use dots in the database name" : "%s anda tidak boleh menggunakan karakter titik pada nama basis data",
    "Cannot write into \"config\" directory" : "Tidak dapat menulis kedalam direktori \"config\"",
    "Cannot write into \"apps\" directory" : "Tidak dapat menulis kedalam direktori \"apps\"",
    "Setting locale to %s failed" : "Pengaturan lokal ke %s gagal",
    "Please install one of these locales on your system and restart your webserver." : "Mohon instal paling tidak satu lokal pada sistem Anda dan jalankan ulang server web.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload diatur menjadi \"%s\" bukan nilai yang diharapkan \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Untuk memperbaiki masalah ini, atur <code>mbstring.func_overload</code> menjadi <code>0</code> pada berkas php.ini Anda",
    "PostgreSQL >= 9 required" : "Diperlukan PostgreSQL >= 9",
    "Please upgrade your database version" : "Mohon perbarui versi basis data Anda",
    "Check the value of \"datadirectory\" in your configuration" : "Periksa nilai \"datadirectory\" di konfigurasi Anda"
},
"nplurals=1; plural=0;");
